pub struct Signpost {}Trait Implementations
Sourceimpl Component for Signpost
impl Component for Signpost
Sourcetype Properties = Props
type Properties = Props
The Component’s properties. Read more
Sourcetype Message = ()
type Message = ()
Messages are used to make Components dynamic and interactive. Simple
Component’s can declare their Message type to be
(). Complex Component’s
commonly use an enum to declare multiple Message types.Sourcefn view(&self, ctx: &Context<Self>) -> Html
fn view(&self, ctx: &Context<Self>) -> Html
Components define their visual layout using a JSX-style syntax through the use of the
html! procedural macro. The full guide to using the macro can be found in Yew’s
documentation. Read moreSourcefn update(&mut self, ctx: &Context<Self>, msg: Self::Message) -> bool
fn update(&mut self, ctx: &Context<Self>, msg: Self::Message) -> bool
Called when a new message is sent to the component via its scope. Read more
Sourcefn changed(
&mut self,
ctx: &Context<Self>,
_old_props: &Self::Properties,
) -> bool
fn changed( &mut self, ctx: &Context<Self>, _old_props: &Self::Properties, ) -> bool
Called when properties passed to the component change Read more
Sourcefn rendered(&mut self, ctx: &Context<Self>, first_render: bool)
fn rendered(&mut self, ctx: &Context<Self>, first_render: bool)
The
rendered method is called after each time a Component is rendered but
before the browser updates the page. Read moreAuto Trait Implementations
impl Freeze for Signpost
impl RefUnwindSafe for Signpost
impl Send for Signpost
impl Sync for Signpost
impl Unpin for Signpost
impl UnsafeUnpin for Signpost
impl UnwindSafe for Signpost